==> haskell-mintty-0.1.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mintty
version: 0.1.1
id: mintty-0.1.1-5pAMEmpWcFDFkMLqWRTQo7
key: mintty-0.1.1-5pAMEmpWcFDFkMLqWRTQo7
license: BSD3
copyright: (C) 2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/mintty
synopsis: A reliable way to detect the presence of a MinTTY console on Windows
description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.
    .
    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.Console.MinTTY
abi: 92114cd4bc25edfe8a147446edca8eb4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mintty-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/mintty-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mintty-0.1.1
hs-libraries: HSmintty-0.1.1-5pAMEmpWcFDFkMLqWRTQo7
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html: /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mintty-0.1.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mintty
version: 0.1.2
id: mintty-0.1.2-JbzlJTT95QQ6PkuXy4kGuG
key: mintty-0.1.2-JbzlJTT95QQ6PkuXy4kGuG
license: BSD-3-Clause
copyright: (C) 2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Ryan Scott
stability: Provisional
homepage: https://github.com/RyanGlScott/mintty
synopsis: A reliable way to detect the presence of a MinTTY console on Windows
description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.
    .
    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.
category: System
abi: fb64a806d52bd659dd92d82dc4c72394
exposed: True
exposed-modules:
    System.Console.MinTTY
import-dirs: /usr/lib/ghc-8.4.3/site-local/mintty-0.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/mintty-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/mintty-0.1.2
hs-libraries: HSmintty-0.1.2-JbzlJTT95QQ6PkuXy4kGuG
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html: /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
